==> illuminaHumanDASLBeadID.db_1.2.0.tar.gz: illuminaHumanDASLBeadID.db/man/illuminaHumanDASLBeadID_dbconn.Rd <==
\name{illuminaHumanDASLBeadID_dbconn}

\alias{illuminaHumanDASLBeadID_dbconn}
\alias{illuminaHumanDASLBeadID_dbfile}
\alias{illuminaHumanDASLBeadID_dbschema}
\alias{illuminaHumanDASLBeadID_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaHumanDASLBeadID_dbconn()
  illuminaHumanDASLBeadID_dbfile()
  illuminaHumanDASLBeadID_dbschema(file="", show.indices=FALSE)
  illuminaHumanDASLBeadID_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaHumanDASLBeadID_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{illuminaHumanDASLBeadID_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{illuminaHumanDASLBeadID_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaHumanDASLBeadID_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaHumanDASLBeadID_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaHumanDASLBeadID_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{illuminaHumanDASLBeadID_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaHumanDASLBeadID_dbschema}: none (invisible \code{NULL}).

  \code{illuminaHumanDASLBeadID_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaHumanDASLBeadID_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaHumanDASLBeadID_dbconn() was created with:
  dbConnect(SQLite(), dbname=illuminaHumanDASLBeadID_dbfile(), cache_size=64000, synchronous=0)

  illuminaHumanDASLBeadID_dbschema()

  illuminaHumanDASLBeadID_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> illuminaHumanDASLBeadID.db_1.6.0.tar.gz: illuminaHumanDASLBeadID.db/man/illuminaHumanDASLBeadID_dbconn.Rd <==

\name{illuminaHumanDASLBeadID_dbconn}

\alias{illuminaHumanDASLBeadID_dbconn}
\alias{illuminaHumanDASLBeadID_dbfile}
\alias{illuminaHumanDASLBeadID_dbschema}
\alias{illuminaHumanDASLBeadID_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaHumanDASLBeadID_dbconn()
  illuminaHumanDASLBeadID_dbfile()
  illuminaHumanDASLBeadID_dbschema(file="", show.indices=FALSE)
  illuminaHumanDASLBeadID_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaHumanDASLBeadID_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{illuminaHumanDASLBeadID_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{illuminaHumanDASLBeadID_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaHumanDASLBeadID_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaHumanDASLBeadID_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaHumanDASLBeadID_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{illuminaHumanDASLBeadID_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaHumanDASLBeadID_dbschema}: none (invisible \code{NULL}).

  \code{illuminaHumanDASLBeadID_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaHumanDASLBeadID_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaHumanDASLBeadID_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=illuminaHumanDASLBeadID_dbfile(), cache_size=64000,
  synchronous=0)

  illuminaHumanDASLBeadID_dbschema()

  illuminaHumanDASLBeadID_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
